print.mcca.pdi.var: Print Method for mcca pdi.var class

View source: R/utils.R

print.mcca.pdi.varR Documentation

Print Method for mcca pdi.var class

Description

An S3 method for the print generic. It is designed for a quick look at PDI values with variance estimation.

Usage

## S3 method for class 'mcca.pdi.var'
print(x, ...)

Arguments

x

object of class 'mcca.pdi.var'.

...

further arguments to 'print.default'.

Value

An object of class "mcca.pdi.var" is a list containing at least the following components:

call

the matched call.

measure

the overall PDI value.

se

the bootstrap standard error of the overall PDI.

ci

the confidence interval for the overall PDI.

level

the confidence level used.

B

the number of bootstrap samples used.

table

a data frame with category-specific PDI values, standard errors, and confidence intervals.

Author(s)

Ming Gao: gaoming@umich.edu

Jialiang Li: stalj@nus.edu.sg

References

Dover, D.C., Savu, A., Engel, B. (2021). Polytomous discrimination index: Estimation and inference. Statistics in Medicine.

Li, J., Gao, M., D'Agostino, R. (2019). Evaluating Classification Accuracy for Modern Learning Approaches. Statistics in Medicine (Tutorials in Biostatistics). 38(13): 2477-2503.

Examples

data = iris[, 1:4]
label = iris[, 5]
pdi_var_object = pdi_var(y = label, d = data, method = "multinom",
                         B = 50, trace = FALSE)
print(pdi_var_object)


mcca documentation built on Feb. 17, 2026, 9:07 a.m.